==> jc-1.4.0.tar.gz: soot/jimple/parser/node/AByteBaseType.h <==
// public final class soot.jimple.parser.node.AByteBaseType

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 8f68debda9b1ff18 soot_jimple_parser_node_AByteBaseType
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class 5816fe0bb21d8c7b soot_jimple_parser_node_PBaseType

// header file dependencies
// @dep_header soot_jimple_parser_node_PBaseType

#include "soot/jimple/parser/node/PBaseType.h"

#ifndef _JC_soot_jimple_parser_node_AByteBaseType_H_
#define _JC_soot_jimple_parser_node_AByteBaseType_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TByte$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_AByteBaseType$sub_refs	_jc_soot_jimple_parser_node_AByteBaseType$sub_refs;
typedef struct _jc_soot_jimple_parser_node_AByteBaseType$sub_nonrefs	_jc_soot_jimple_parser_node_AByteBaseType$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_AByteBaseType$refs	_jc_soot_jimple_parser_node_AByteBaseType$refs;
typedef struct _jc_soot_jimple_parser_node_AByteBaseType$nonrefs	_jc_soot_jimple_parser_node_AByteBaseType$nonrefs;
typedef struct _jc_soot_jimple_parser_node_AByteBaseType$object	_jc_soot_jimple_parser_node_AByteBaseType$object;

typedef const struct _jc_soot_jimple_parser_node_AByteBaseType$vmethods	_jc_soot_jimple_parser_node_AByteBaseType$vmethods;
typedef const struct _jc_soot_jimple_parser_node_AByteBaseType$vtable	_jc_soot_jimple_parser_node_AByteBaseType$vtable;
typedef const struct _jc_soot_jimple_parser_node_AByteBaseType$vtype	_jc_soot_jimple_parser_node_AByteBaseType$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_AByteBaseType$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_AByteBaseType$object *);
extern void _jc_soot_jimple_parser_node_AByteBaseType$method$_init$9f18d4f12c033c34(_jc_env *, struct _jc_soot_jimple_parser_node_AByteBaseType$object *, struct _jc_soot_jimple_parser_node_TByte$object *);

// Virtual methods
extern void _jc_soot_jimple_parser_node_AByteBaseType$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_AByteBaseType$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_AByteBaseType$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_AByteBaseType$object *);
extern struct _jc_soot_jimple_parser_node_TByte$object *_jc_soot_jimple_parser_node_AByteBaseType$method$getByte$14c0877f290cf23e(_jc_env *, struct _jc_soot_jimple_parser_node_AByteBaseType$object *);
extern void _jc_soot_jimple_parser_node_AByteBaseType$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_AByteBaseType$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_AByteBaseType$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_AByteBaseType$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_AByteBaseType$method$setByte$785e88c48049cbb1(_jc_env *, struct _jc_soot_jimple_parser_node_AByteBaseType$object *, struct _jc_soot_jimple_parser_node_TByte$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_AByteBaseType$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_AByteBaseType$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_AByteBaseType$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_AByteBaseType$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_AByteBaseType$method_info$getByte$14c0877f290cf23e;
extern _jc_method _jc_soot_jimple_parser_node_AByteBaseType$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_AByteBaseType$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_AByteBaseType$method_info$setByte$785e88c48049cbb1;
extern _jc_method _jc_soot_jimple_parser_node_AByteBaseType$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_AByteBaseType$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_AByteBaseType$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_AByteBaseType$object *);
	struct _jc_soot_jimple_parser_node_TByte$object	*(*getByte$14c0877f290cf23e)(_jc_env *, struct _jc_soot_jimple_parser_node_AByteBaseType$object *);
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_AByteBaseType$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_AByteBaseType$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*setByte$785e88c48049cbb1)(_jc_env *, struct _jc_soot_jimple_parser_node_AByteBaseType$object *, struct _jc_soot_jimple_parser_node_TByte$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_AByteBaseType$object *);
};

// Vtable
struct _jc_soot_jimple_parser_node_AByteBaseType$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PBaseType$vmethods	soot_jimple_parser_node_PBaseType;
	_jc_soot_jimple_parser_node_AByteBaseType$vmethods	soot_jimple_parser_node_AByteBaseType;
};

// Vtype
struct _jc_soot_jimple_parser_node_AByteBaseType$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_AByteBaseType$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AByteBaseType$sub_refs {
	struct _jc_soot_jimple_parser_node_TByte$object	*__5fbyte__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_AByteBaseType$refs {
    _jc_soot_jimple_parser_node_AByteBaseType$sub_refs	soot_jimple_parser_node_AByteBaseType;
    _jc_soot_jimple_parser_node_PBaseType$sub_refs	soot_jimple_parser_node_PBaseType;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AByteBaseType$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_AByteBaseType$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PBaseType$sub_nonrefs	soot_jimple_parser_node_PBaseType;
    _jc_soot_jimple_parser_node_AByteBaseType$sub_nonrefs	soot_jimple_parser_node_AByteBaseType;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_AByteBaseType$object {
	_jc_soot_jimple_parser_node_AByteBaseType$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_AByteBaseType$vtype	*vtype;
	_jc_soot_jimple_parser_node_AByteBaseType$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_AByteBaseType$vtype _jc_soot_jimple_parser_node_AByteBaseType$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_AByteBaseType, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_AByteBaseType$class_object;

#endif	/* _JC_soot_jimple_parser_node_AByteBaseType_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/node/AByteBaseType.h <==
// public final class soot.jimple.parser.node.AByteBaseType

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 8f68debda9b1ff18 soot_jimple_parser_node_AByteBaseType
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class 5816fe0bb21d8c7b soot_jimple_parser_node_PBaseType

// header file dependencies
// @dep_header soot_jimple_parser_node_PBaseType

#include "soot/jimple/parser/node/PBaseType.h"

#ifndef _JC_soot_jimple_parser_node_AByteBaseType_H_
#define _JC_soot_jimple_parser_node_AByteBaseType_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TByte$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_AByteBaseType$sub_refs	_jc_soot_jimple_parser_node_AByteBaseType$sub_refs;
typedef struct _jc_soot_jimple_parser_node_AByteBaseType$sub_nonrefs	_jc_soot_jimple_parser_node_AByteBaseType$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_AByteBaseType$refs	_jc_soot_jimple_parser_node_AByteBaseType$refs;
typedef struct _jc_soot_jimple_parser_node_AByteBaseType$nonrefs	_jc_soot_jimple_parser_node_AByteBaseType$nonrefs;
typedef struct _jc_soot_jimple_parser_node_AByteBaseType$object	_jc_soot_jimple_parser_node_AByteBaseType$object;

typedef const struct _jc_soot_jimple_parser_node_AByteBaseType$vmethods	_jc_soot_jimple_parser_node_AByteBaseType$vmethods;
typedef const struct _jc_soot_jimple_parser_node_AByteBaseType$vtable	_jc_soot_jimple_parser_node_AByteBaseType$vtable;
typedef const struct _jc_soot_jimple_parser_node_AByteBaseType$vtype	_jc_soot_jimple_parser_node_AByteBaseType$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_AByteBaseType$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_AByteBaseType$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AByteBaseType$method$_init$9f18d4f12c033c34(_jc_env *, struct _jc_soot_jimple_parser_node_AByteBaseType$object *, struct _jc_soot_jimple_parser_node_TByte$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_parser_node_AByteBaseType$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_AByteBaseType$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_AByteBaseType$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_AByteBaseType$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_parser_node_TByte$object *_jc_soot_jimple_parser_node_AByteBaseType$method$getByte$14c0877f290cf23e(_jc_env *, struct _jc_soot_jimple_parser_node_AByteBaseType$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AByteBaseType$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_AByteBaseType$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AByteBaseType$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_AByteBaseType$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AByteBaseType$method$setByte$785e88c48049cbb1(_jc_env *, struct _jc_soot_jimple_parser_node_AByteBaseType$object *, struct _jc_soot_jimple_parser_node_TByte$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_AByteBaseType$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_AByteBaseType$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_AByteBaseType$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_AByteBaseType$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_AByteBaseType$method_info$getByte$14c0877f290cf23e;
extern _jc_method _jc_soot_jimple_parser_node_AByteBaseType$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_AByteBaseType$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_AByteBaseType$method_info$setByte$785e88c48049cbb1;
extern _jc_method _jc_soot_jimple_parser_node_AByteBaseType$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_AByteBaseType$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_AByteBaseType$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_AByteBaseType$object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_parser_node_TByte$object	*(*getByte$14c0877f290cf23e)(_jc_env *, struct _jc_soot_jimple_parser_node_AByteBaseType$object *) _JC_JCNI_ATTR;
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_AByteBaseType$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_AByteBaseType$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*setByte$785e88c48049cbb1)(_jc_env *, struct _jc_soot_jimple_parser_node_AByteBaseType$object *, struct _jc_soot_jimple_parser_node_TByte$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_AByteBaseType$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_parser_node_AByteBaseType$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PBaseType$vmethods	soot_jimple_parser_node_PBaseType;
	_jc_soot_jimple_parser_node_AByteBaseType$vmethods	soot_jimple_parser_node_AByteBaseType;
};

// Vtype
struct _jc_soot_jimple_parser_node_AByteBaseType$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_AByteBaseType$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AByteBaseType$sub_refs {
	struct _jc_soot_jimple_parser_node_TByte$object	*__5fbyte__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_AByteBaseType$refs {
    _jc_soot_jimple_parser_node_AByteBaseType$sub_refs	soot_jimple_parser_node_AByteBaseType;
    _jc_soot_jimple_parser_node_PBaseType$sub_refs	soot_jimple_parser_node_PBaseType;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AByteBaseType$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_AByteBaseType$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PBaseType$sub_nonrefs	soot_jimple_parser_node_PBaseType;
    _jc_soot_jimple_parser_node_AByteBaseType$sub_nonrefs	soot_jimple_parser_node_AByteBaseType;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_AByteBaseType$object {
	_jc_soot_jimple_parser_node_AByteBaseType$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_AByteBaseType$vtype	*vtype;
	_jc_soot_jimple_parser_node_AByteBaseType$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_AByteBaseType$vtype _jc_soot_jimple_parser_node_AByteBaseType$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_AByteBaseType, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_AByteBaseType$class_object;

#endif	/* _JC_soot_jimple_parser_node_AByteBaseType_H_ */
